# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class L2Site(Base):
	"""The L2Site class encapsulates a user managed l2Site node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the L2Site property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'l2Site'

	def __init__(self, parent):
		super(L2Site, self).__init__(parent)

	@property
	def Cluster(self):
		"""An instance of the Cluster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster.Cluster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster import Cluster
		return Cluster(self)._select()

	@property
	def LabelBlock(self):
		"""An instance of the LabelBlock class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelblock.LabelBlock)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelblock import LabelBlock
		return LabelBlock(self)

	@property
	def LearnedRoute(self):
		"""An instance of the LearnedRoute class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedroute.LearnedRoute)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.learnedroute import LearnedRoute
		return LearnedRoute(self)

	@property
	def MacAddressRange(self):
		"""An instance of the MacAddressRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.macaddressrange.MacAddressRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.macaddressrange import MacAddressRange
		return MacAddressRange(self)

	@property
	def DistinguishAssignedIncrement(self):
		"""Distinguishes increment of the assigned value

		Returns:
			number
		"""
		return self._get_attribute('distinguishAssignedIncrement')
	@DistinguishAssignedIncrement.setter
	def DistinguishAssignedIncrement(self, value):
		self._set_attribute('distinguishAssignedIncrement', value)

	@property
	def DistinguishIpIncrement(self):
		"""Distinguishes the increment of the IP address

		Returns:
			str
		"""
		return self._get_attribute('distinguishIpIncrement')
	@DistinguishIpIncrement.setter
	def DistinguishIpIncrement(self, value):
		self._set_attribute('distinguishIpIncrement', value)

	@property
	def DistinguishNumberIncrementAs(self):
		"""Signifies the distinguished increment as number

		Returns:
			number
		"""
		return self._get_attribute('distinguishNumberIncrementAs')
	@DistinguishNumberIncrementAs.setter
	def DistinguishNumberIncrementAs(self, value):
		self._set_attribute('distinguishNumberIncrementAs', value)

	@property
	def EnableBfdVccv(self):
		"""If true, enables BFD VCCV

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdVccv')
	@EnableBfdVccv.setter
	def EnableBfdVccv(self, value):
		self._set_attribute('enableBfdVccv', value)

	@property
	def EnableCluster(self):
		"""Enables and controls the use of L2 VPN VPLS.

		Returns:
			bool
		"""
		return self._get_attribute('enableCluster')
	@EnableCluster.setter
	def EnableCluster(self, value):
		self._set_attribute('enableCluster', value)

	@property
	def EnableControlWord(self):
		"""Enables the use of a control word, as part of the extended community information.

		Returns:
			bool
		"""
		return self._get_attribute('enableControlWord')
	@EnableControlWord.setter
	def EnableControlWord(self, value):
		self._set_attribute('enableControlWord', value)

	@property
	def EnableL2SiteAsTrafficEndpoint(self):
		"""If true, enables L2 site as traffic endpoint

		Returns:
			bool
		"""
		return self._get_attribute('enableL2SiteAsTrafficEndpoint')
	@EnableL2SiteAsTrafficEndpoint.setter
	def EnableL2SiteAsTrafficEndpoint(self, value):
		self._set_attribute('enableL2SiteAsTrafficEndpoint', value)

	@property
	def EnableSequenceDelivery(self):
		"""Enables the use of sequenced delivery of frames, as part of the extended community information.

		Returns:
			bool
		"""
		return self._get_attribute('enableSequenceDelivery')
	@EnableSequenceDelivery.setter
	def EnableSequenceDelivery(self, value):
		self._set_attribute('enableSequenceDelivery', value)

	@property
	def EnableVccvPing(self):
		"""If true, enables the VCCV ping

		Returns:
			bool
		"""
		return self._get_attribute('enableVccvPing')
	@EnableVccvPing.setter
	def EnableVccvPing(self, value):
		self._set_attribute('enableVccvPing', value)

	@property
	def Enabled(self):
		"""Enables or disables use of the L2 VPN site.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def IsLearnedInfoRefreshed(self):
		"""If true, learned information is refreshed.

		Returns:
			bool
		"""
		return self._get_attribute('isLearnedInfoRefreshed')

	@property
	def Mtu(self):
		"""The Maximum Transmission Unit (MTU) allowed on this link, in bytes. The valid range is 0 to 16777215. (default = 1,500 bytes)

		Returns:
			number
		"""
		return self._get_attribute('mtu')
	@Mtu.setter
	def Mtu(self, value):
		self._set_attribute('mtu', value)

	@property
	def NoOfL2Site(self):
		"""Signifies the number of L2 sites

		Returns:
			number
		"""
		return self._get_attribute('noOfL2Site')
	@NoOfL2Site.setter
	def NoOfL2Site(self, value):
		self._set_attribute('noOfL2Site', value)

	@property
	def RouteDistinguisherAs(self):
		"""Available for use only if the route distinguish type is set to AS. The route distinguisher autonomous system (AS) number.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAs')
	@RouteDistinguisherAs.setter
	def RouteDistinguisherAs(self, value):
		self._set_attribute('routeDistinguisherAs', value)

	@property
	def RouteDistinguisherAssignedNum(self):
		"""The assigned number for use with the distinguisher IP address or AS number, to create the route distinguisher.The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAssignedNum')
	@RouteDistinguisherAssignedNum.setter
	def RouteDistinguisherAssignedNum(self, value):
		self._set_attribute('routeDistinguisherAssignedNum', value)

	@property
	def RouteDistinguisherIp(self):
		"""Available for use only if the route Distinguish Type is set to IP. The route distinguisher IP address. A 4-byte IPv4 address.The default is 0.0.0.0.

		Returns:
			str
		"""
		return self._get_attribute('routeDistinguisherIp')
	@RouteDistinguisherIp.setter
	def RouteDistinguisherIp(self, value):
		self._set_attribute('routeDistinguisherIp', value)

	@property
	def RouteDistinguisherType(self):
		"""Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.

		Returns:
			str(twoOctetAs|ip|fourOctetAs)
		"""
		return self._get_attribute('routeDistinguisherType')
	@RouteDistinguisherType.setter
	def RouteDistinguisherType(self, value):
		self._set_attribute('routeDistinguisherType', value)

	@property
	def RouteTargetAs(self):
		"""Autonomous system (AS) number. A 2-byte AS number, used to create the route target extended community attribute associated with this L2 site.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAs')
	@RouteTargetAs.setter
	def RouteTargetAs(self, value):
		self._set_attribute('routeTargetAs', value)

	@property
	def RouteTargetAssignedNum(self):
		"""Autonomous system (AS) and assigned number. A 2-byte AS number and a 4-byte assigned number, used to create the route target extended community attribute associated with this L2 site.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAssignedNum')
	@RouteTargetAssignedNum.setter
	def RouteTargetAssignedNum(self, value):
		self._set_attribute('routeTargetAssignedNum', value)

	@property
	def RouteTargetIp(self):
		"""IP address and assigned number. A 4-byte IPv4 address and a 2-byte assigned number, used to create the route target extended community attribute associated with this L2 site.

		Returns:
			str
		"""
		return self._get_attribute('routeTargetIp')
	@RouteTargetIp.setter
	def RouteTargetIp(self, value):
		self._set_attribute('routeTargetIp', value)

	@property
	def RouteTargetType(self):
		"""The Admin part type is to the type of route target attribute

		Returns:
			str(as|ip)
		"""
		return self._get_attribute('routeTargetType')
	@RouteTargetType.setter
	def RouteTargetType(self, value):
		self._set_attribute('routeTargetType', value)

	@property
	def SiteId(self):
		"""The identifier for the L2 (CE) site. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('siteId')
	@SiteId.setter
	def SiteId(self, value):
		self._set_attribute('siteId', value)

	@property
	def SiteIdIncrement(self):
		"""Increments the site identifier

		Returns:
			number
		"""
		return self._get_attribute('siteIdIncrement')
	@SiteIdIncrement.setter
	def SiteIdIncrement(self, value):
		self._set_attribute('siteIdIncrement', value)

	@property
	def TargetAssignedNumberIncrement(self):
		"""Signifies increment of the target assigned number

		Returns:
			number
		"""
		return self._get_attribute('targetAssignedNumberIncrement')
	@TargetAssignedNumberIncrement.setter
	def TargetAssignedNumberIncrement(self, value):
		self._set_attribute('targetAssignedNumberIncrement', value)

	@property
	def TargetIncrementAs(self):
		"""Signifies increment as target

		Returns:
			number
		"""
		return self._get_attribute('targetIncrementAs')
	@TargetIncrementAs.setter
	def TargetIncrementAs(self, value):
		self._set_attribute('targetIncrementAs', value)

	@property
	def TargetIpIncrement(self):
		"""Signifies the increment of IP as target

		Returns:
			str
		"""
		return self._get_attribute('targetIpIncrement')
	@TargetIpIncrement.setter
	def TargetIpIncrement(self, value):
		self._set_attribute('targetIpIncrement', value)

	@property
	def TrafficGroupId(self):
		"""Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	def update(self, DistinguishAssignedIncrement=None, DistinguishIpIncrement=None, DistinguishNumberIncrementAs=None, EnableBfdVccv=None, EnableCluster=None, EnableControlWord=None, EnableL2SiteAsTrafficEndpoint=None, EnableSequenceDelivery=None, EnableVccvPing=None, Enabled=None, Mtu=None, NoOfL2Site=None, RouteDistinguisherAs=None, RouteDistinguisherAssignedNum=None, RouteDistinguisherIp=None, RouteDistinguisherType=None, RouteTargetAs=None, RouteTargetAssignedNum=None, RouteTargetIp=None, RouteTargetType=None, SiteId=None, SiteIdIncrement=None, TargetAssignedNumberIncrement=None, TargetIncrementAs=None, TargetIpIncrement=None, TrafficGroupId=None):
		"""Updates a child instance of l2Site on the server.

		Args:
			DistinguishAssignedIncrement (number): Distinguishes increment of the assigned value
			DistinguishIpIncrement (str): Distinguishes the increment of the IP address
			DistinguishNumberIncrementAs (number): Signifies the distinguished increment as number
			EnableBfdVccv (bool): If true, enables BFD VCCV
			EnableCluster (bool): Enables and controls the use of L2 VPN VPLS.
			EnableControlWord (bool): Enables the use of a control word, as part of the extended community information.
			EnableL2SiteAsTrafficEndpoint (bool): If true, enables L2 site as traffic endpoint
			EnableSequenceDelivery (bool): Enables the use of sequenced delivery of frames, as part of the extended community information.
			EnableVccvPing (bool): If true, enables the VCCV ping
			Enabled (bool): Enables or disables use of the L2 VPN site.
			Mtu (number): The Maximum Transmission Unit (MTU) allowed on this link, in bytes. The valid range is 0 to 16777215. (default = 1,500 bytes)
			NoOfL2Site (number): Signifies the number of L2 sites
			RouteDistinguisherAs (number): Available for use only if the route distinguish type is set to AS. The route distinguisher autonomous system (AS) number.
			RouteDistinguisherAssignedNum (number): The assigned number for use with the distinguisher IP address or AS number, to create the route distinguisher.The default is 0.
			RouteDistinguisherIp (str): Available for use only if the route Distinguish Type is set to IP. The route distinguisher IP address. A 4-byte IPv4 address.The default is 0.0.0.0.
			RouteDistinguisherType (str(twoOctetAs|ip|fourOctetAs)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			RouteTargetAs (number): Autonomous system (AS) number. A 2-byte AS number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetAssignedNum (number): Autonomous system (AS) and assigned number. A 2-byte AS number and a 4-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetIp (str): IP address and assigned number. A 4-byte IPv4 address and a 2-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetType (str(as|ip)): The Admin part type is to the type of route target attribute
			SiteId (number): The identifier for the L2 (CE) site. The default is 0.
			SiteIdIncrement (number): Increments the site identifier
			TargetAssignedNumberIncrement (number): Signifies increment of the target assigned number
			TargetIncrementAs (number): Signifies increment as target
			TargetIpIncrement (str): Signifies the increment of IP as target
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, DistinguishAssignedIncrement=None, DistinguishIpIncrement=None, DistinguishNumberIncrementAs=None, EnableBfdVccv=None, EnableCluster=None, EnableControlWord=None, EnableL2SiteAsTrafficEndpoint=None, EnableSequenceDelivery=None, EnableVccvPing=None, Enabled=None, Mtu=None, NoOfL2Site=None, RouteDistinguisherAs=None, RouteDistinguisherAssignedNum=None, RouteDistinguisherIp=None, RouteDistinguisherType=None, RouteTargetAs=None, RouteTargetAssignedNum=None, RouteTargetIp=None, RouteTargetType=None, SiteId=None, SiteIdIncrement=None, TargetAssignedNumberIncrement=None, TargetIncrementAs=None, TargetIpIncrement=None, TrafficGroupId=None):
		"""Adds a new l2Site node on the server and retrieves it in this instance.

		Args:
			DistinguishAssignedIncrement (number): Distinguishes increment of the assigned value
			DistinguishIpIncrement (str): Distinguishes the increment of the IP address
			DistinguishNumberIncrementAs (number): Signifies the distinguished increment as number
			EnableBfdVccv (bool): If true, enables BFD VCCV
			EnableCluster (bool): Enables and controls the use of L2 VPN VPLS.
			EnableControlWord (bool): Enables the use of a control word, as part of the extended community information.
			EnableL2SiteAsTrafficEndpoint (bool): If true, enables L2 site as traffic endpoint
			EnableSequenceDelivery (bool): Enables the use of sequenced delivery of frames, as part of the extended community information.
			EnableVccvPing (bool): If true, enables the VCCV ping
			Enabled (bool): Enables or disables use of the L2 VPN site.
			Mtu (number): The Maximum Transmission Unit (MTU) allowed on this link, in bytes. The valid range is 0 to 16777215. (default = 1,500 bytes)
			NoOfL2Site (number): Signifies the number of L2 sites
			RouteDistinguisherAs (number): Available for use only if the route distinguish type is set to AS. The route distinguisher autonomous system (AS) number.
			RouteDistinguisherAssignedNum (number): The assigned number for use with the distinguisher IP address or AS number, to create the route distinguisher.The default is 0.
			RouteDistinguisherIp (str): Available for use only if the route Distinguish Type is set to IP. The route distinguisher IP address. A 4-byte IPv4 address.The default is 0.0.0.0.
			RouteDistinguisherType (str(twoOctetAs|ip|fourOctetAs)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			RouteTargetAs (number): Autonomous system (AS) number. A 2-byte AS number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetAssignedNum (number): Autonomous system (AS) and assigned number. A 2-byte AS number and a 4-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetIp (str): IP address and assigned number. A 4-byte IPv4 address and a 2-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetType (str(as|ip)): The Admin part type is to the type of route target attribute
			SiteId (number): The identifier for the L2 (CE) site. The default is 0.
			SiteIdIncrement (number): Increments the site identifier
			TargetAssignedNumberIncrement (number): Signifies increment of the target assigned number
			TargetIncrementAs (number): Signifies increment as target
			TargetIpIncrement (str): Signifies the increment of IP as target
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			self: This instance with all currently retrieved l2Site data using find and the newly added l2Site data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the l2Site data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, DistinguishAssignedIncrement=None, DistinguishIpIncrement=None, DistinguishNumberIncrementAs=None, EnableBfdVccv=None, EnableCluster=None, EnableControlWord=None, EnableL2SiteAsTrafficEndpoint=None, EnableSequenceDelivery=None, EnableVccvPing=None, Enabled=None, IsLearnedInfoRefreshed=None, Mtu=None, NoOfL2Site=None, RouteDistinguisherAs=None, RouteDistinguisherAssignedNum=None, RouteDistinguisherIp=None, RouteDistinguisherType=None, RouteTargetAs=None, RouteTargetAssignedNum=None, RouteTargetIp=None, RouteTargetType=None, SiteId=None, SiteIdIncrement=None, TargetAssignedNumberIncrement=None, TargetIncrementAs=None, TargetIpIncrement=None, TrafficGroupId=None):
		"""Finds and retrieves l2Site data from the server.

		All named parameters support regex and can be used to selectively retrieve l2Site data from the server.
		By default the find method takes no parameters and will retrieve all l2Site data from the server.

		Args:
			DistinguishAssignedIncrement (number): Distinguishes increment of the assigned value
			DistinguishIpIncrement (str): Distinguishes the increment of the IP address
			DistinguishNumberIncrementAs (number): Signifies the distinguished increment as number
			EnableBfdVccv (bool): If true, enables BFD VCCV
			EnableCluster (bool): Enables and controls the use of L2 VPN VPLS.
			EnableControlWord (bool): Enables the use of a control word, as part of the extended community information.
			EnableL2SiteAsTrafficEndpoint (bool): If true, enables L2 site as traffic endpoint
			EnableSequenceDelivery (bool): Enables the use of sequenced delivery of frames, as part of the extended community information.
			EnableVccvPing (bool): If true, enables the VCCV ping
			Enabled (bool): Enables or disables use of the L2 VPN site.
			IsLearnedInfoRefreshed (bool): If true, learned information is refreshed.
			Mtu (number): The Maximum Transmission Unit (MTU) allowed on this link, in bytes. The valid range is 0 to 16777215. (default = 1,500 bytes)
			NoOfL2Site (number): Signifies the number of L2 sites
			RouteDistinguisherAs (number): Available for use only if the route distinguish type is set to AS. The route distinguisher autonomous system (AS) number.
			RouteDistinguisherAssignedNum (number): The assigned number for use with the distinguisher IP address or AS number, to create the route distinguisher.The default is 0.
			RouteDistinguisherIp (str): Available for use only if the route Distinguish Type is set to IP. The route distinguisher IP address. A 4-byte IPv4 address.The default is 0.0.0.0.
			RouteDistinguisherType (str(twoOctetAs|ip|fourOctetAs)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			RouteTargetAs (number): Autonomous system (AS) number. A 2-byte AS number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetAssignedNum (number): Autonomous system (AS) and assigned number. A 2-byte AS number and a 4-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetIp (str): IP address and assigned number. A 4-byte IPv4 address and a 2-byte assigned number, used to create the route target extended community attribute associated with this L2 site.
			RouteTargetType (str(as|ip)): The Admin part type is to the type of route target attribute
			SiteId (number): The identifier for the L2 (CE) site. The default is 0.
			SiteIdIncrement (number): Increments the site identifier
			TargetAssignedNumberIncrement (number): Signifies increment of the target assigned number
			TargetIncrementAs (number): Signifies increment as target
			TargetIpIncrement (str): Signifies the increment of IP as target
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): Contains the object reference to a traffic group identifier as configured with the trafficGroup object.

		Returns:
			self: This instance with matching l2Site data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of l2Site data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the l2Site data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def RefreshLearnedInfo(self):
		"""Executes the refreshLearnedInfo operation on the server.

		This function argument allows to refreshe the BGP learned information from the DUT.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLearnedInfo', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class WildcardsSupported(Base):
	"""The WildcardsSupported class encapsulates a required wildcardsSupported node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the WildcardsSupported property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'wildcardsSupported'

	def __init__(self, parent):
		super(WildcardsSupported, self).__init__(parent)

	@property
	def EthernetDestinationAddress(self):
		"""Indicates that the Ethernet destination address is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ethernetDestinationAddress')
	@EthernetDestinationAddress.setter
	def EthernetDestinationAddress(self, value):
		self._set_attribute('ethernetDestinationAddress', value)

	@property
	def EthernetFrameType(self):
		"""Indicates that the Ethernet frame type is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ethernetFrameType')
	@EthernetFrameType.setter
	def EthernetFrameType(self, value):
		self._set_attribute('ethernetFrameType', value)

	@property
	def EthernetSourceAddress(self):
		"""Indicates that the Ethernet source address is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ethernetSourceAddress')
	@EthernetSourceAddress.setter
	def EthernetSourceAddress(self, value):
		self._set_attribute('ethernetSourceAddress', value)

	@property
	def IpDestinationAddress(self):
		"""Indicates that the IP destination address is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ipDestinationAddress')
	@IpDestinationAddress.setter
	def IpDestinationAddress(self, value):
		self._set_attribute('ipDestinationAddress', value)

	@property
	def IpProtocol(self):
		"""Indicates that the IP protocol is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ipProtocol')
	@IpProtocol.setter
	def IpProtocol(self, value):
		self._set_attribute('ipProtocol', value)

	@property
	def IpSourceAddress(self):
		"""Indicates that the IP source address is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ipSourceAddress')
	@IpSourceAddress.setter
	def IpSourceAddress(self, value):
		self._set_attribute('ipSourceAddress', value)

	@property
	def IpTos(self):
		"""Indicates that the IP ToS (DSCP field, 6 bits) is supported.

		Returns:
			bool
		"""
		return self._get_attribute('ipTos')
	@IpTos.setter
	def IpTos(self, value):
		self._set_attribute('ipTos', value)

	@property
	def SwitchInputPort(self):
		"""Indicates that the Switch input port is supported.

		Returns:
			bool
		"""
		return self._get_attribute('switchInputPort')
	@SwitchInputPort.setter
	def SwitchInputPort(self, value):
		self._set_attribute('switchInputPort', value)

	@property
	def TcpUdpDestinationPort(self):
		"""Indicates that the TCP/UDP destination port is supported.

		Returns:
			bool
		"""
		return self._get_attribute('tcpUdpDestinationPort')
	@TcpUdpDestinationPort.setter
	def TcpUdpDestinationPort(self, value):
		self._set_attribute('tcpUdpDestinationPort', value)

	@property
	def TcpUdpSourcePort(self):
		"""Indicates that the TCP/UDP source port is supported.

		Returns:
			bool
		"""
		return self._get_attribute('tcpUdpSourcePort')
	@TcpUdpSourcePort.setter
	def TcpUdpSourcePort(self, value):
		self._set_attribute('tcpUdpSourcePort', value)

	@property
	def VlanId(self):
		"""Indicates that the VLAN id is supported.

		Returns:
			bool
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	@property
	def VlanPriority(self):
		"""Indicates that the VLAN priority is supported.

		Returns:
			bool
		"""
		return self._get_attribute('vlanPriority')
	@VlanPriority.setter
	def VlanPriority(self, value):
		self._set_attribute('vlanPriority', value)

	def update(self, EthernetDestinationAddress=None, EthernetFrameType=None, EthernetSourceAddress=None, IpDestinationAddress=None, IpProtocol=None, IpSourceAddress=None, IpTos=None, SwitchInputPort=None, TcpUdpDestinationPort=None, TcpUdpSourcePort=None, VlanId=None, VlanPriority=None):
		"""Updates a child instance of wildcardsSupported on the server.

		Args:
			EthernetDestinationAddress (bool): Indicates that the Ethernet destination address is supported.
			EthernetFrameType (bool): Indicates that the Ethernet frame type is supported.
			EthernetSourceAddress (bool): Indicates that the Ethernet source address is supported.
			IpDestinationAddress (bool): Indicates that the IP destination address is supported.
			IpProtocol (bool): Indicates that the IP protocol is supported.
			IpSourceAddress (bool): Indicates that the IP source address is supported.
			IpTos (bool): Indicates that the IP ToS (DSCP field, 6 bits) is supported.
			SwitchInputPort (bool): Indicates that the Switch input port is supported.
			TcpUdpDestinationPort (bool): Indicates that the TCP/UDP destination port is supported.
			TcpUdpSourcePort (bool): Indicates that the TCP/UDP source port is supported.
			VlanId (bool): Indicates that the VLAN id is supported.
			VlanPriority (bool): Indicates that the VLAN priority is supported.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Iptv(Base):
	"""The Iptv class encapsulates a required iptv node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Iptv property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'iptv'

	def __init__(self, parent):
		super(Iptv, self).__init__(parent)

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableGeneralQueryResponse(self):
		"""If enabled, General Query Response is send.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableGeneralQueryResponse')

	@property
	def EnableGroupSpecificQueryResponse(self):
		"""If enabled, Group Specific Response is sent

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableGroupSpecificQueryResponse')

	@property
	def JoinLatencyThreshold(self):
		"""The maximum time that is allowed for a multicast stream to arrive for channel for which a Join has been sent.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('joinLatencyThreshold')

	@property
	def LeaveLatencyThreshold(self):
		"""The maximum time allowed for a multicast stream to stop for a channel for which a Leave has been sent.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('leaveLatencyThreshold')

	@property
	def LogAllTimestamps(self):
		"""If enabled, all the captured timestamps for Join and Leave are saved to a log file.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('logAllTimestamps')

	@property
	def LogFailureTimestamps(self):
		"""If enabled, the timestamps for Join and Leave failures are saved to a log file.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('logFailureTimestamps')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumChannelChangesBeforeView(self):
		"""Number of channels to change before stopping on a channel and watching it for View Duration.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('numChannelChangesBeforeView')

	@property
	def State(self):
		"""Indicates the state IPTV

		Returns:
			list(str[notStarted|started])
		"""
		return self._get_attribute('state')

	@property
	def StbLeaveJoinDelay(self):
		"""Time in milliseconds between sending a Leave for the current channel and Join for the next channel.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('stbLeaveJoinDelay')

	@property
	def ViewDuration(self):
		"""Specifies the time in milliseconds to view the last channel.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('viewDuration')

	@property
	def ZapBehavior(self):
		"""Use Zap Only to change channels without viewing the channel or Zap and View to change traffic and receive traffic for the last channel.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('zapBehavior')

	@property
	def ZapDirection(self):
		"""Specifies the direction of changing channels.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('zapDirection')

	@property
	def ZapInterval(self):
		"""Interval in milliseconds between channel changes based on the selected type.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('zapInterval')

	@property
	def ZapIntervalType(self):
		"""Specifies the wait interval type before changing the channels.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('zapIntervalType')

	def update(self, Name=None):
		"""Updates a child instance of iptv on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, EnableGeneralQueryResponse=None, EnableGroupSpecificQueryResponse=None, JoinLatencyThreshold=None, LeaveLatencyThreshold=None, LogAllTimestamps=None, LogFailureTimestamps=None, NumChannelChangesBeforeView=None, StbLeaveJoinDelay=None, ViewDuration=None, ZapBehavior=None, ZapDirection=None, ZapInterval=None, ZapIntervalType=None):
		"""Base class infrastructure that gets a list of iptv device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			EnableGeneralQueryResponse (str): optional regex of enableGeneralQueryResponse
			EnableGroupSpecificQueryResponse (str): optional regex of enableGroupSpecificQueryResponse
			JoinLatencyThreshold (str): optional regex of joinLatencyThreshold
			LeaveLatencyThreshold (str): optional regex of leaveLatencyThreshold
			LogAllTimestamps (str): optional regex of logAllTimestamps
			LogFailureTimestamps (str): optional regex of logFailureTimestamps
			NumChannelChangesBeforeView (str): optional regex of numChannelChangesBeforeView
			StbLeaveJoinDelay (str): optional regex of stbLeaveJoinDelay
			ViewDuration (str): optional regex of viewDuration
			ZapBehavior (str): optional regex of zapBehavior
			ZapDirection (str): optional regex of zapDirection
			ZapInterval (str): optional regex of zapInterval
			ZapIntervalType (str): optional regex of zapIntervalType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def StartIptv(self, *args, **kwargs):
		"""Executes the startIptv operation on the server.

		Start IPTV

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startIptv()

		startIptv(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		startIptv(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		startIptv(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the IPTV grid An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startIptv', payload=payload, response_object=None)

	def StopIptv(self, *args, **kwargs):
		"""Executes the stopIptv operation on the server.

		Stop IPTV

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopIptv()

		stopIptv(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopIptv(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stopIptv(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the IPTV grid An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopIptv', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Config(Base):
	"""The Config class encapsulates a required config node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Config property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'config'

	def __init__(self, parent):
		super(Config, self).__init__(parent)

	@property
	def NoFlood(self):
		"""Indicates that the port is not included when flooding.

		Returns:
			bool
		"""
		return self._get_attribute('noFlood')
	@NoFlood.setter
	def NoFlood(self, value):
		self._set_attribute('noFlood', value)

	@property
	def NoForward(self):
		"""Indicates that the port drop all packets forwarded to it.

		Returns:
			bool
		"""
		return self._get_attribute('noForward')
	@NoForward.setter
	def NoForward(self, value):
		self._set_attribute('noForward', value)

	@property
	def NoPacketIn(self):
		"""Indicates that the port does not send packet-in messages.

		Returns:
			bool
		"""
		return self._get_attribute('noPacketIn')
	@NoPacketIn.setter
	def NoPacketIn(self, value):
		self._set_attribute('noPacketIn', value)

	@property
	def NoReceive(self):
		"""Indicates that the port drops all packets except 802.1D spanning tree packets.

		Returns:
			bool
		"""
		return self._get_attribute('noReceive')
	@NoReceive.setter
	def NoReceive(self, value):
		self._set_attribute('noReceive', value)

	@property
	def NoReceiveStp(self):
		"""Indicates that the port drops received 802.1D STP packets.

		Returns:
			bool
		"""
		return self._get_attribute('noReceiveStp')
	@NoReceiveStp.setter
	def NoReceiveStp(self, value):
		self._set_attribute('noReceiveStp', value)

	@property
	def NoStp(self):
		"""Indicates that 802.1D spanning tree on port is disable.

		Returns:
			bool
		"""
		return self._get_attribute('noStp')
	@NoStp.setter
	def NoStp(self, value):
		self._set_attribute('noStp', value)

	@property
	def PortDown(self):
		"""Indicates that the port is administratively down.

		Returns:
			bool
		"""
		return self._get_attribute('portDown')
	@PortDown.setter
	def PortDown(self, value):
		self._set_attribute('portDown', value)

	def update(self, NoFlood=None, NoForward=None, NoPacketIn=None, NoReceive=None, NoReceiveStp=None, NoStp=None, PortDown=None):
		"""Updates a child instance of config on the server.

		Args:
			NoFlood (bool): Indicates that the port is not included when flooding.
			NoForward (bool): Indicates that the port drop all packets forwarded to it.
			NoPacketIn (bool): Indicates that the port does not send packet-in messages.
			NoReceive (bool): Indicates that the port drops all packets except 802.1D spanning tree packets.
			NoReceiveStp (bool): Indicates that the port drops received 802.1D STP packets.
			NoStp (bool): Indicates that 802.1D spanning tree on port is disable.
			PortDown (bool): Indicates that the port is administratively down.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# Copyright 1997 - 2018 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from ixnetwork_restpy.base import Base
from ixnetwork_restpy.errors import IxNetworkError


class Sessions(Base):
    """Sessions class

    Manage IxNetwork sessions based on the connection information provided to the TestPlatform class.

    Child classes:  
        Sessions.Ixnetwork
    """
    _SDM_NAME = 'sessions'
    
    def __init__(self, parent):
        super(Sessions, self).__init__(parent)

    @property
    def Ixnetwork(self):
        """An instance of the Ixnetwork class
        
        Returns: 
            obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.ixnetwork.Ixnetwork):

        Raises: 
            ValueError: If the version of IxNetwork server is not suporrted. The minimum version supported is 8.42.
        """
        from ixnetwork_restpy.testplatform.sessions.ixnetwork.ixnetwork import Ixnetwork
        ixnetwork = Ixnetwork(self)
        build_number = ixnetwork._connection._read('%s/ixnetwork/globals' % self.href)['buildNumber']
        from distutils.version import LooseVersion
        if LooseVersion(build_number) < LooseVersion('8.42'):
            raise ValueError('IxNetwork server version %s is not supported. The minimum version supported is 8.42' % build_number)
        ixnetwork._set_properties(ixnetwork._connection._read('%s/%s' % (self.href, Ixnetwork._SDM_NAME)))
        return ixnetwork
    
    @property
    def State(self):
        """The state of the session

        Returns:
            str
        """
        return self._properties['state'].upper()
    
    @property
    def ApplicationType(self):
        """The application type of the session

        Returns:
            str
        """
        return self._properties['applicationType']
    
    @property
    def Id(self):
        """The id of the session

        Returns:
            number
        """
        return self._properties['id']
    
    @property
    def UserId(self):
        """The user id of the session

        Returns:
            str
        """
        return self._properties['userId']
    
    @property
    def UserName(self):
        """The user name of the session

        Returns:
            str
        """
        return self._properties['userName']

    def Start(self):
        """Starts the session

        Returns:
            None
        """
        if self._connection._platform != 'windows':
            response = self._execute('start', payload={'applicationType': self.ApplicationType})
            if response is not None:
                self._set_properties(response, clear=True)
    
    def find(self, Id=None):
        """Finds all child instances of Sessions on the server.

        Raises:
            ServerError: The server has encountered an uncategorized error condition
        """
        responses = self._connection._read('%s/%s' % (self._parent.href, self._SDM_NAME))
        self._clear()
        for response in responses:
            if Id is not None:
                if str(response['id']) == str(Id):
                    self._set_properties(response)
            else:
                self._set_properties(response)
        return self

    def add(self):
        """Adds a new sessions node on the server and retrieves it in this instance.

        Raises:
            ServerError: The server has encountered an uncategorized error condition
        """
        applicationType = 'ixnrest'
        self._create(locals())
        if self._connection._platform == 'linux':
            self.Start()
        return self

    def remove(self):
        """Deletes all the sessions data in this instance from server.

        Raises:
            NotFoundError: The requested resource does not exist on the server
            ServerError: The server has encountered an uncategorized error condition
        """
        try:
            self._execute('stop')
            self._delete()
        except IxNetworkError as e:
            if e._status_code not in [404, 405]:
                raise e
    
    def GetObjectFromHref(self, href):
        """Given an href get the corresponding object
        
        References are used to establish relationships between disparate nodes.
        This allows a user to get an object using a reference from a node.
        For example:
            A /vport node has a ConnectedTo property that is a reference to an /availableHardware/chassis/card/port node.
            A user can get a vport and use this method to get the port node in order to clear ownership
        
        Args:
            href (str): A valid href reference

        Returns:
            obj | None: If the reference is valid an ixnetwork_restpy object or None if the reference cannot be resolved
        """
        try:
            node = self
            for piece in href[href.find('ixnetwork'):].split('/'):
                if piece.isdigit():
                    for item in node:
                        if item.href.split('/').pop() == piece:
                            node = node._read(item.href)
                            break
                else:
                    class_name = '%s%s' % (piece[0].upper(), piece[1:])
                    node = getattr(node, class_name)
                    if hasattr(node, 'find') is True:
                        node.find()
            return node
        except:
            return None

    def GetFileList(self, remote_directory=None):
        """Get a list of files from the IxNetwork session instance

        Args:
            remote_directory (str): A remote directory path

        Returns:
            dict(root_path, list(dict(filename, filesize)): A list of all the files for a given directory
        """
        href = '%s/ixnetwork/files' % self.href
        if remote_directory is not None:
            href = '%s?absolute=remote_directory'
        return self._connection._read(href)

    def DownloadFile(self, remote_filename, local_filename = None):
        """Download a file from the IxNetwork session instance

        Args:
            remote_fileanme (str): the name of the remote file
            local_filename (str): the name that the remote contents will be saved to
        
        Returns:
            str: the local file name
        """
        return self._connection._get_file('%s/ixnetwork' % self.href, remote_filename=remote_filename, local_filename=local_filename)
    
    def UploadFile(self, local_filename, remote_filename=None):
        """Upload a file to the IxNetwork session instance

        Args:
            local_filename (str): the name of the local file
            remote_filename (str): the name that will be used when saving the file on the IxNetwork sesson instance
        
        Returns:
            dict(filename, filesize): Details of the file that was uploaded
        """
        return self._connection._put_file('%s/ixnetwork' % self.href, local_filename=local_filename, remote_filename=remote_filename)


# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PacketOutTriggerActions(Base):
	"""The PacketOutTriggerActions class encapsulates a user managed packetOutTriggerActions node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PacketOutTriggerActions property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'packetOutTriggerActions'

	def __init__(self, parent):
		super(PacketOutTriggerActions, self).__init__(parent)

	@property
	def ActionType(self):
		"""The action type associated with this instruction.

		Returns:
			str(drop|output|setEthernetSource|setEthernetDestination|setEthernetType|setVlanId|setVlanPriority|setIpDscp|setIpEcn|setIpProtocol|setIpv4Source|setIpv4Destination|setTcpSource|setTcpDestination|setUdpSource|setUdpDestination|setSctpSource|setSctpDestination|setIcmpv4Type|setIcmpv4Code|setArpOpcode|setArpSourceHwAddress|setArpTargetHwAddress|setArpSourceIpv4Address|setArpTargetIpv4Address|setIpv6Source|setIpv6Destination|setIpv6FlowLabel|setIcmpv6Type|setIcmpv6Code|setIpv6NdTarget|setIpv6NdSll|setIpv6NdTll|setMplsLabel|setMplsTc|setMplsBos|setPbbIsid|setTunnelId|setIpv6ExtHeader|copyTtlOut|copyTtlIn|setMplsTtl|decrementMplsTtl|pushVlan|popVlan|pushMpls|popMpls|setQueue|group|setNetworkTtl|decrementNetworkTtl|pushPbb|popPbb|experimenter)
		"""
		return self._get_attribute('actionType')
	@ActionType.setter
	def ActionType(self, value):
		self._set_attribute('actionType', value)

	@property
	def ArpDstHwAddr(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('arpDstHwAddr')
	@ArpDstHwAddr.setter
	def ArpDstHwAddr(self, value):
		self._set_attribute('arpDstHwAddr', value)

	@property
	def ArpDstIpv4Addr(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('arpDstIpv4Addr')
	@ArpDstIpv4Addr.setter
	def ArpDstIpv4Addr(self, value):
		self._set_attribute('arpDstIpv4Addr', value)

	@property
	def ArpOpcode(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('arpOpcode')
	@ArpOpcode.setter
	def ArpOpcode(self, value):
		self._set_attribute('arpOpcode', value)

	@property
	def ArpSrcHwAddr(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('arpSrcHwAddr')
	@ArpSrcHwAddr.setter
	def ArpSrcHwAddr(self, value):
		self._set_attribute('arpSrcHwAddr', value)

	@property
	def ArpSrcIpv4Addr(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('arpSrcIpv4Addr')
	@ArpSrcIpv4Addr.setter
	def ArpSrcIpv4Addr(self, value):
		self._set_attribute('arpSrcIpv4Addr', value)

	@property
	def EthernetDestination(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestination')
	@EthernetDestination.setter
	def EthernetDestination(self, value):
		self._set_attribute('ethernetDestination', value)

	@property
	def EthernetSource(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ethernetSource')
	@EthernetSource.setter
	def EthernetSource(self, value):
		self._set_attribute('ethernetSource', value)

	@property
	def EthernetType(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ethernetType')
	@EthernetType.setter
	def EthernetType(self, value):
		self._set_attribute('ethernetType', value)

	@property
	def Experimenter(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('experimenter')
	@Experimenter.setter
	def Experimenter(self, value):
		self._set_attribute('experimenter', value)

	@property
	def ExperimenterData(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('experimenterData')
	@ExperimenterData.setter
	def ExperimenterData(self, value):
		self._set_attribute('experimenterData', value)

	@property
	def ExperimenterDatalength(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('experimenterDatalength')
	@ExperimenterDatalength.setter
	def ExperimenterDatalength(self, value):
		self._set_attribute('experimenterDatalength', value)

	@property
	def GroupId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('groupId')
	@GroupId.setter
	def GroupId(self, value):
		self._set_attribute('groupId', value)

	@property
	def Icmpv4Code(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('icmpv4Code')
	@Icmpv4Code.setter
	def Icmpv4Code(self, value):
		self._set_attribute('icmpv4Code', value)

	@property
	def Icmpv4Type(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('icmpv4Type')
	@Icmpv4Type.setter
	def Icmpv4Type(self, value):
		self._set_attribute('icmpv4Type', value)

	@property
	def Icmpv6Code(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('icmpv6Code')
	@Icmpv6Code.setter
	def Icmpv6Code(self, value):
		self._set_attribute('icmpv6Code', value)

	@property
	def Icmpv6Type(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('icmpv6Type')
	@Icmpv6Type.setter
	def Icmpv6Type(self, value):
		self._set_attribute('icmpv6Type', value)

	@property
	def IpDscp(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ipDscp')
	@IpDscp.setter
	def IpDscp(self, value):
		self._set_attribute('ipDscp', value)

	@property
	def IpEcn(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ipEcn')
	@IpEcn.setter
	def IpEcn(self, value):
		self._set_attribute('ipEcn', value)

	@property
	def IpProtocol(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ipProtocol')
	@IpProtocol.setter
	def IpProtocol(self, value):
		self._set_attribute('ipProtocol', value)

	@property
	def Ipv4Destination(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv4Destination')
	@Ipv4Destination.setter
	def Ipv4Destination(self, value):
		self._set_attribute('ipv4Destination', value)

	@property
	def Ipv4Source(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv4Source')
	@Ipv4Source.setter
	def Ipv4Source(self, value):
		self._set_attribute('ipv4Source', value)

	@property
	def Ipv6Destination(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv6Destination')
	@Ipv6Destination.setter
	def Ipv6Destination(self, value):
		self._set_attribute('ipv6Destination', value)

	@property
	def Ipv6ExtHeader(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ipv6ExtHeader')
	@Ipv6ExtHeader.setter
	def Ipv6ExtHeader(self, value):
		self._set_attribute('ipv6ExtHeader', value)

	@property
	def Ipv6FlowLabel(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('ipv6FlowLabel')
	@Ipv6FlowLabel.setter
	def Ipv6FlowLabel(self, value):
		self._set_attribute('ipv6FlowLabel', value)

	@property
	def Ipv6NdSll(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdSll')
	@Ipv6NdSll.setter
	def Ipv6NdSll(self, value):
		self._set_attribute('ipv6NdSll', value)

	@property
	def Ipv6NdTll(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdTll')
	@Ipv6NdTll.setter
	def Ipv6NdTll(self, value):
		self._set_attribute('ipv6NdTll', value)

	@property
	def Ipv6Source(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv6Source')
	@Ipv6Source.setter
	def Ipv6Source(self, value):
		self._set_attribute('ipv6Source', value)

	@property
	def Ipv6ndTarget(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ipv6ndTarget')
	@Ipv6ndTarget.setter
	def Ipv6ndTarget(self, value):
		self._set_attribute('ipv6ndTarget', value)

	@property
	def MaxByteLength(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('maxByteLength')
	@MaxByteLength.setter
	def MaxByteLength(self, value):
		self._set_attribute('maxByteLength', value)

	@property
	def MplsBos(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('mplsBos')
	@MplsBos.setter
	def MplsBos(self, value):
		self._set_attribute('mplsBos', value)

	@property
	def MplsLabel(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('mplsLabel')
	@MplsLabel.setter
	def MplsLabel(self, value):
		self._set_attribute('mplsLabel', value)

	@property
	def MplsTc(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('mplsTc')
	@MplsTc.setter
	def MplsTc(self, value):
		self._set_attribute('mplsTc', value)

	@property
	def MplsTtl(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('mplsTtl')
	@MplsTtl.setter
	def MplsTtl(self, value):
		self._set_attribute('mplsTtl', value)

	@property
	def NwTtl(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('nwTtl')
	@NwTtl.setter
	def NwTtl(self, value):
		self._set_attribute('nwTtl', value)

	@property
	def OutputPort(self):
		"""The Output port number to be used.

		Returns:
			number
		"""
		return self._get_attribute('outputPort')
	@OutputPort.setter
	def OutputPort(self, value):
		self._set_attribute('outputPort', value)

	@property
	def OutputPortType(self):
		"""NOT DEFINED

		Returns:
			str(ofppInPort|manual|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppTable)
		"""
		return self._get_attribute('outputPortType')
	@OutputPortType.setter
	def OutputPortType(self, value):
		self._set_attribute('outputPortType', value)

	@property
	def PbbISid(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('pbbISid')
	@PbbISid.setter
	def PbbISid(self, value):
		self._set_attribute('pbbISid', value)

	@property
	def QueueId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('queueId')
	@QueueId.setter
	def QueueId(self, value):
		self._set_attribute('queueId', value)

	@property
	def SctpDestination(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('sctpDestination')
	@SctpDestination.setter
	def SctpDestination(self, value):
		self._set_attribute('sctpDestination', value)

	@property
	def SctpSource(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('sctpSource')
	@SctpSource.setter
	def SctpSource(self, value):
		self._set_attribute('sctpSource', value)

	@property
	def TcpDestination(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tcpDestination')
	@TcpDestination.setter
	def TcpDestination(self, value):
		self._set_attribute('tcpDestination', value)

	@property
	def TcpSource(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tcpSource')
	@TcpSource.setter
	def TcpSource(self, value):
		self._set_attribute('tcpSource', value)

	@property
	def TunnelId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('tunnelId')
	@TunnelId.setter
	def TunnelId(self, value):
		self._set_attribute('tunnelId', value)

	@property
	def UdpDestination(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('udpDestination')
	@UdpDestination.setter
	def UdpDestination(self, value):
		self._set_attribute('udpDestination', value)

	@property
	def UdpSource(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('udpSource')
	@UdpSource.setter
	def UdpSource(self, value):
		self._set_attribute('udpSource', value)

	@property
	def VlanId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	@property
	def VlanPriority(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('vlanPriority')
	@VlanPriority.setter
	def VlanPriority(self, value):
		self._set_attribute('vlanPriority', value)

	def update(self, ActionType=None, ArpDstHwAddr=None, ArpDstIpv4Addr=None, ArpOpcode=None, ArpSrcHwAddr=None, ArpSrcIpv4Addr=None, EthernetDestination=None, EthernetSource=None, EthernetType=None, Experimenter=None, ExperimenterData=None, ExperimenterDatalength=None, GroupId=None, Icmpv4Code=None, Icmpv4Type=None, Icmpv6Code=None, Icmpv6Type=None, IpDscp=None, IpEcn=None, IpProtocol=None, Ipv4Destination=None, Ipv4Source=None, Ipv6Destination=None, Ipv6ExtHeader=None, Ipv6FlowLabel=None, Ipv6NdSll=None, Ipv6NdTll=None, Ipv6Source=None, Ipv6ndTarget=None, MaxByteLength=None, MplsBos=None, MplsLabel=None, MplsTc=None, MplsTtl=None, NwTtl=None, OutputPort=None, OutputPortType=None, PbbISid=None, QueueId=None, SctpDestination=None, SctpSource=None, TcpDestination=None, TcpSource=None, TunnelId=None, UdpDestination=None, UdpSource=None, VlanId=None, VlanPriority=None):
		"""Updates a child instance of packetOutTriggerActions on the server.

		Args:
			ActionType (str(drop|output|setEthernetSource|setEthernetDestination|setEthernetType|setVlanId|setVlanPriority|setIpDscp|setIpEcn|setIpProtocol|setIpv4Source|setIpv4Destination|setTcpSource|setTcpDestination|setUdpSource|setUdpDestination|setSctpSource|setSctpDestination|setIcmpv4Type|setIcmpv4Code|setArpOpcode|setArpSourceHwAddress|setArpTargetHwAddress|setArpSourceIpv4Address|setArpTargetIpv4Address|setIpv6Source|setIpv6Destination|setIpv6FlowLabel|setIcmpv6Type|setIcmpv6Code|setIpv6NdTarget|setIpv6NdSll|setIpv6NdTll|setMplsLabel|setMplsTc|setMplsBos|setPbbIsid|setTunnelId|setIpv6ExtHeader|copyTtlOut|copyTtlIn|setMplsTtl|decrementMplsTtl|pushVlan|popVlan|pushMpls|popMpls|setQueue|group|setNetworkTtl|decrementNetworkTtl|pushPbb|popPbb|experimenter)): The action type associated with this instruction.
			ArpDstHwAddr (str): NOT DEFINED
			ArpDstIpv4Addr (number): NOT DEFINED
			ArpOpcode (number): NOT DEFINED
			ArpSrcHwAddr (str): NOT DEFINED
			ArpSrcIpv4Addr (number): NOT DEFINED
			EthernetDestination (str): NOT DEFINED
			EthernetSource (str): NOT DEFINED
			EthernetType (number): NOT DEFINED
			Experimenter (number): NOT DEFINED
			ExperimenterData (str): NOT DEFINED
			ExperimenterDatalength (number): NOT DEFINED
			GroupId (number): NOT DEFINED
			Icmpv4Code (number): NOT DEFINED
			Icmpv4Type (number): NOT DEFINED
			Icmpv6Code (number): NOT DEFINED
			Icmpv6Type (number): NOT DEFINED
			IpDscp (number): NOT DEFINED
			IpEcn (number): NOT DEFINED
			IpProtocol (number): NOT DEFINED
			Ipv4Destination (str): NOT DEFINED
			Ipv4Source (str): NOT DEFINED
			Ipv6Destination (str): NOT DEFINED
			Ipv6ExtHeader (number): NOT DEFINED
			Ipv6FlowLabel (number): NOT DEFINED
			Ipv6NdSll (str): NOT DEFINED
			Ipv6NdTll (str): NOT DEFINED
			Ipv6Source (str): NOT DEFINED
			Ipv6ndTarget (str): NOT DEFINED
			MaxByteLength (number): NOT DEFINED
			MplsBos (number): NOT DEFINED
			MplsLabel (number): NOT DEFINED
			MplsTc (number): NOT DEFINED
			MplsTtl (number): NOT DEFINED
			NwTtl (number): NOT DEFINED
			OutputPort (number): The Output port number to be used.
			OutputPortType (str(ofppInPort|manual|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppTable)): NOT DEFINED
			PbbISid (number): NOT DEFINED
			QueueId (number): NOT DEFINED
			SctpDestination (number): NOT DEFINED
			SctpSource (number): NOT DEFINED
			TcpDestination (number): NOT DEFINED
			TcpSource (number): NOT DEFINED
			TunnelId (number): NOT DEFINED
			UdpDestination (number): NOT DEFINED
			UdpSource (number): NOT DEFINED
			VlanId (number): NOT DEFINED
			VlanPriority (number): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ActionType=None, ArpDstHwAddr=None, ArpDstIpv4Addr=None, ArpOpcode=None, ArpSrcHwAddr=None, ArpSrcIpv4Addr=None, EthernetDestination=None, EthernetSource=None, EthernetType=None, Experimenter=None, ExperimenterData=None, ExperimenterDatalength=None, GroupId=None, Icmpv4Code=None, Icmpv4Type=None, Icmpv6Code=None, Icmpv6Type=None, IpDscp=None, IpEcn=None, IpProtocol=None, Ipv4Destination=None, Ipv4Source=None, Ipv6Destination=None, Ipv6ExtHeader=None, Ipv6FlowLabel=None, Ipv6NdSll=None, Ipv6NdTll=None, Ipv6Source=None, Ipv6ndTarget=None, MaxByteLength=None, MplsBos=None, MplsLabel=None, MplsTc=None, MplsTtl=None, NwTtl=None, OutputPort=None, OutputPortType=None, PbbISid=None, QueueId=None, SctpDestination=None, SctpSource=None, TcpDestination=None, TcpSource=None, TunnelId=None, UdpDestination=None, UdpSource=None, VlanId=None, VlanPriority=None):
		"""Adds a new packetOutTriggerActions node on the server and retrieves it in this instance.

		Args:
			ActionType (str(drop|output|setEthernetSource|setEthernetDestination|setEthernetType|setVlanId|setVlanPriority|setIpDscp|setIpEcn|setIpProtocol|setIpv4Source|setIpv4Destination|setTcpSource|setTcpDestination|setUdpSource|setUdpDestination|setSctpSource|setSctpDestination|setIcmpv4Type|setIcmpv4Code|setArpOpcode|setArpSourceHwAddress|setArpTargetHwAddress|setArpSourceIpv4Address|setArpTargetIpv4Address|setIpv6Source|setIpv6Destination|setIpv6FlowLabel|setIcmpv6Type|setIcmpv6Code|setIpv6NdTarget|setIpv6NdSll|setIpv6NdTll|setMplsLabel|setMplsTc|setMplsBos|setPbbIsid|setTunnelId|setIpv6ExtHeader|copyTtlOut|copyTtlIn|setMplsTtl|decrementMplsTtl|pushVlan|popVlan|pushMpls|popMpls|setQueue|group|setNetworkTtl|decrementNetworkTtl|pushPbb|popPbb|experimenter)): The action type associated with this instruction.
			ArpDstHwAddr (str): NOT DEFINED
			ArpDstIpv4Addr (number): NOT DEFINED
			ArpOpcode (number): NOT DEFINED
			ArpSrcHwAddr (str): NOT DEFINED
			ArpSrcIpv4Addr (number): NOT DEFINED
			EthernetDestination (str): NOT DEFINED
			EthernetSource (str): NOT DEFINED
			EthernetType (number): NOT DEFINED
			Experimenter (number): NOT DEFINED
			ExperimenterData (str): NOT DEFINED
			ExperimenterDatalength (number): NOT DEFINED
			GroupId (number): NOT DEFINED
			Icmpv4Code (number): NOT DEFINED
			Icmpv4Type (number): NOT DEFINED
			Icmpv6Code (number): NOT DEFINED
			Icmpv6Type (number): NOT DEFINED
			IpDscp (number): NOT DEFINED
			IpEcn (number): NOT DEFINED
			IpProtocol (number): NOT DEFINED
			Ipv4Destination (str): NOT DEFINED
			Ipv4Source (str): NOT DEFINED
			Ipv6Destination (str): NOT DEFINED
			Ipv6ExtHeader (number): NOT DEFINED
			Ipv6FlowLabel (number): NOT DEFINED
			Ipv6NdSll (str): NOT DEFINED
			Ipv6NdTll (str): NOT DEFINED
			Ipv6Source (str): NOT DEFINED
			Ipv6ndTarget (str): NOT DEFINED
			MaxByteLength (number): NOT DEFINED
			MplsBos (number): NOT DEFINED
			MplsLabel (number): NOT DEFINED
			MplsTc (number): NOT DEFINED
			MplsTtl (number): NOT DEFINED
			NwTtl (number): NOT DEFINED
			OutputPort (number): The Output port number to be used.
			OutputPortType (str(ofppInPort|manual|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppTable)): NOT DEFINED
			PbbISid (number): NOT DEFINED
			QueueId (number): NOT DEFINED
			SctpDestination (number): NOT DEFINED
			SctpSource (number): NOT DEFINED
			TcpDestination (number): NOT DEFINED
			TcpSource (number): NOT DEFINED
			TunnelId (number): NOT DEFINED
			UdpDestination (number): NOT DEFINED
			UdpSource (number): NOT DEFINED
			VlanId (number): NOT DEFINED
			VlanPriority (number): NOT DEFINED

		Returns:
			self: This instance with all currently retrieved packetOutTriggerActions data using find and the newly added packetOutTriggerActions data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the packetOutTriggerActions data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ActionType=None, ArpDstHwAddr=None, ArpDstIpv4Addr=None, ArpOpcode=None, ArpSrcHwAddr=None, ArpSrcIpv4Addr=None, EthernetDestination=None, EthernetSource=None, EthernetType=None, Experimenter=None, ExperimenterData=None, ExperimenterDatalength=None, GroupId=None, Icmpv4Code=None, Icmpv4Type=None, Icmpv6Code=None, Icmpv6Type=None, IpDscp=None, IpEcn=None, IpProtocol=None, Ipv4Destination=None, Ipv4Source=None, Ipv6Destination=None, Ipv6ExtHeader=None, Ipv6FlowLabel=None, Ipv6NdSll=None, Ipv6NdTll=None, Ipv6Source=None, Ipv6ndTarget=None, MaxByteLength=None, MplsBos=None, MplsLabel=None, MplsTc=None, MplsTtl=None, NwTtl=None, OutputPort=None, OutputPortType=None, PbbISid=None, QueueId=None, SctpDestination=None, SctpSource=None, TcpDestination=None, TcpSource=None, TunnelId=None, UdpDestination=None, UdpSource=None, VlanId=None, VlanPriority=None):
		"""Finds and retrieves packetOutTriggerActions data from the server.

		All named parameters support regex and can be used to selectively retrieve packetOutTriggerActions data from the server.
		By default the find method takes no parameters and will retrieve all packetOutTriggerActions data from the server.

		Args:
			ActionType (str(drop|output|setEthernetSource|setEthernetDestination|setEthernetType|setVlanId|setVlanPriority|setIpDscp|setIpEcn|setIpProtocol|setIpv4Source|setIpv4Destination|setTcpSource|setTcpDestination|setUdpSource|setUdpDestination|setSctpSource|setSctpDestination|setIcmpv4Type|setIcmpv4Code|setArpOpcode|setArpSourceHwAddress|setArpTargetHwAddress|setArpSourceIpv4Address|setArpTargetIpv4Address|setIpv6Source|setIpv6Destination|setIpv6FlowLabel|setIcmpv6Type|setIcmpv6Code|setIpv6NdTarget|setIpv6NdSll|setIpv6NdTll|setMplsLabel|setMplsTc|setMplsBos|setPbbIsid|setTunnelId|setIpv6ExtHeader|copyTtlOut|copyTtlIn|setMplsTtl|decrementMplsTtl|pushVlan|popVlan|pushMpls|popMpls|setQueue|group|setNetworkTtl|decrementNetworkTtl|pushPbb|popPbb|experimenter)): The action type associated with this instruction.
			ArpDstHwAddr (str): NOT DEFINED
			ArpDstIpv4Addr (number): NOT DEFINED
			ArpOpcode (number): NOT DEFINED
			ArpSrcHwAddr (str): NOT DEFINED
			ArpSrcIpv4Addr (number): NOT DEFINED
			EthernetDestination (str): NOT DEFINED
			EthernetSource (str): NOT DEFINED
			EthernetType (number): NOT DEFINED
			Experimenter (number): NOT DEFINED
			ExperimenterData (str): NOT DEFINED
			ExperimenterDatalength (number): NOT DEFINED
			GroupId (number): NOT DEFINED
			Icmpv4Code (number): NOT DEFINED
			Icmpv4Type (number): NOT DEFINED
			Icmpv6Code (number): NOT DEFINED
			Icmpv6Type (number): NOT DEFINED
			IpDscp (number): NOT DEFINED
			IpEcn (number): NOT DEFINED
			IpProtocol (number): NOT DEFINED
			Ipv4Destination (str): NOT DEFINED
			Ipv4Source (str): NOT DEFINED
			Ipv6Destination (str): NOT DEFINED
			Ipv6ExtHeader (number): NOT DEFINED
			Ipv6FlowLabel (number): NOT DEFINED
			Ipv6NdSll (str): NOT DEFINED
			Ipv6NdTll (str): NOT DEFINED
			Ipv6Source (str): NOT DEFINED
			Ipv6ndTarget (str): NOT DEFINED
			MaxByteLength (number): NOT DEFINED
			MplsBos (number): NOT DEFINED
			MplsLabel (number): NOT DEFINED
			MplsTc (number): NOT DEFINED
			MplsTtl (number): NOT DEFINED
			NwTtl (number): NOT DEFINED
			OutputPort (number): The Output port number to be used.
			OutputPortType (str(ofppInPort|manual|ofppNormal|ofppFlood|ofppAll|ofppController|ofppLocal|ofppTable)): NOT DEFINED
			PbbISid (number): NOT DEFINED
			QueueId (number): NOT DEFINED
			SctpDestination (number): NOT DEFINED
			SctpSource (number): NOT DEFINED
			TcpDestination (number): NOT DEFINED
			TcpSource (number): NOT DEFINED
			TunnelId (number): NOT DEFINED
			UdpDestination (number): NOT DEFINED
			UdpSource (number): NOT DEFINED
			VlanId (number): NOT DEFINED
			VlanPriority (number): NOT DEFINED

		Returns:
			self: This instance with matching packetOutTriggerActions data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of packetOutTriggerActions data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the packetOutTriggerActions data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Tracking(Base):
	"""The Tracking class encapsulates a system managed tracking node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Tracking property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'tracking'

	def __init__(self, parent):
		super(Tracking, self).__init__(parent)

	@property
	def Egress(self):
		"""An instance of the DEPRECATED Egress class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.tracking.egress.egress.Egress)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.tracking.egress.egress import Egress
		return Egress(self)._select()

	@property
	def LatencyBin(self):
		"""An instance of the LatencyBin class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.tracking.latencybin.latencybin.LatencyBin)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.tracking.latencybin.latencybin import LatencyBin
		return LatencyBin(self)._select()

	@property
	def AvailableProtocolOffsets(self):
		"""Specifies the available Protocol Offsets when the Flows of a Traffic Item are tracked by Custom Override.

		Returns:
			list(str)
		"""
		return self._get_attribute('availableProtocolOffsets')

	@property
	def AvailableTrackBy(self):
		"""DEPRECATED Returns list of available tracking field ids

		Returns:
			list(str)
		"""
		return self._get_attribute('availableTrackBy')

	@property
	def AvailableTrackByInfos(self):
		"""DEPRECATED Returns list of tracking fields with id/displayname

		Returns:
			list(dict(arg1:str,arg2:str))
		"""
		return self._get_attribute('availableTrackByInfos')

	@property
	def FieldWidth(self):
		"""DEPRECATED Specifies the Field Width when the flows of a Traffic Item are tracked by Custom Override.

		Returns:
			str(eightBits|sixteenBits|thirtyTwoBits|twentyFourBits)
		"""
		return self._get_attribute('fieldWidth')
	@FieldWidth.setter
	def FieldWidth(self, value):
		self._set_attribute('fieldWidth', value)

	@property
	def Offset(self):
		"""DEPRECATED Specifies the Offset when the Flows of a Traffic Item are tracked by Custom Override.

		Returns:
			number
		"""
		return self._get_attribute('offset')
	@Offset.setter
	def Offset(self, value):
		self._set_attribute('offset', value)

	@property
	def OneToOneMesh(self):
		"""DEPRECATED If true, one-one mesh is enabled when flows of a traffic item are tracked by Custom Override.

		Returns:
			bool
		"""
		return self._get_attribute('oneToOneMesh')
	@OneToOneMesh.setter
	def OneToOneMesh(self, value):
		self._set_attribute('oneToOneMesh', value)

	@property
	def ProtocolOffset(self):
		"""DEPRECATED Specifies the Protocol Offset when flows of a Traffic Item are tracked by Custom Override.

		Returns:
			str
		"""
		return self._get_attribute('protocolOffset')
	@ProtocolOffset.setter
	def ProtocolOffset(self, value):
		self._set_attribute('protocolOffset', value)

	@property
	def TrackBy(self):
		"""DEPRECATED Specifies the tracking option by which the Flows of a Traffic Item are tracked.

		Returns:
			list(str)
		"""
		return self._get_attribute('trackBy')
	@TrackBy.setter
	def TrackBy(self, value):
		self._set_attribute('trackBy', value)

	@property
	def Values(self):
		"""DEPRECATED Specifies the Values when the Flows of a Traffic Item are tracked by Custom Override.

		Returns:
			list(str)
		"""
		return self._get_attribute('values')
	@Values.setter
	def Values(self, value):
		self._set_attribute('values', value)

	def update(self, FieldWidth=None, Offset=None, OneToOneMesh=None, ProtocolOffset=None, TrackBy=None, Values=None):
		"""Updates a child instance of tracking on the server.

		Args:
			FieldWidth (str(eightBits|sixteenBits|thirtyTwoBits|twentyFourBits)): Specifies the Field Width when the flows of a Traffic Item are tracked by Custom Override.
			Offset (number): Specifies the Offset when the Flows of a Traffic Item are tracked by Custom Override.
			OneToOneMesh (bool): If true, one-one mesh is enabled when flows of a traffic item are tracked by Custom Override.
			ProtocolOffset (str): Specifies the Protocol Offset when flows of a Traffic Item are tracked by Custom Override.
			TrackBy (list(str)): Specifies the tracking option by which the Flows of a Traffic Item are tracked.
			Values (list(str)): Specifies the Values when the Flows of a Traffic Item are tracked by Custom Override.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, AvailableProtocolOffsets=None, AvailableTrackBy=None, AvailableTrackByInfos=None, FieldWidth=None, Offset=None, OneToOneMesh=None, ProtocolOffset=None, TrackBy=None, Values=None):
		"""Finds and retrieves tracking data from the server.

		All named parameters support regex and can be used to selectively retrieve tracking data from the server.
		By default the find method takes no parameters and will retrieve all tracking data from the server.

		Args:
			AvailableProtocolOffsets (list(str)): Specifies the available Protocol Offsets when the Flows of a Traffic Item are tracked by Custom Override.
			AvailableTrackBy (list(str)): Returns list of available tracking field ids
			AvailableTrackByInfos (list(dict(arg1:str,arg2:str))): Returns list of tracking fields with id/displayname
			FieldWidth (str(eightBits|sixteenBits|thirtyTwoBits|twentyFourBits)): Specifies the Field Width when the flows of a Traffic Item are tracked by Custom Override.
			Offset (number): Specifies the Offset when the Flows of a Traffic Item are tracked by Custom Override.
			OneToOneMesh (bool): If true, one-one mesh is enabled when flows of a traffic item are tracked by Custom Override.
			ProtocolOffset (str): Specifies the Protocol Offset when flows of a Traffic Item are tracked by Custom Override.
			TrackBy (list(str)): Specifies the tracking option by which the Flows of a Traffic Item are tracked.
			Values (list(str)): Specifies the Values when the Flows of a Traffic Item are tracked by Custom Override.

		Returns:
			self: This instance with matching tracking data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of tracking data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the tracking data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TunnelHeadToLeaf(Base):
	"""The TunnelHeadToLeaf class encapsulates a user managed tunnelHeadToLeaf node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TunnelHeadToLeaf property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'tunnelHeadToLeaf'

	def __init__(self, parent):
		super(TunnelHeadToLeaf, self).__init__(parent)

	@property
	def DutHopType(self):
		"""Based on the input, the corresponding L bit in the packet is set.

		Returns:
			str(strict|loose)
		"""
		return self._get_attribute('dutHopType')
	@DutHopType.setter
	def DutHopType(self, value):
		self._set_attribute('dutHopType', value)

	@property
	def DutPrefixLength(self):
		"""Prefix length of DUT.

		Returns:
			number
		"""
		return self._get_attribute('dutPrefixLength')
	@DutPrefixLength.setter
	def DutPrefixLength(self, value):
		self._set_attribute('dutPrefixLength', value)

	@property
	def Enabled(self):
		"""It enables or disables the ERO/SERO specific configuration.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def HeadIpStart(self):
		"""It is the tunnel head IP address for which the ERO/SERO is being configured.

		Returns:
			str
		"""
		return self._get_attribute('headIpStart')

	@property
	def IsAppendTunnelLeaf(self):
		"""If enabled, this appends the tunnel leaf at the end of the ERO/SERO list in the packet.

		Returns:
			bool
		"""
		return self._get_attribute('isAppendTunnelLeaf')
	@IsAppendTunnelLeaf.setter
	def IsAppendTunnelLeaf(self, value):
		self._set_attribute('isAppendTunnelLeaf', value)

	@property
	def IsPrependDut(self):
		"""Enables prepend DUT to the ERO/SERO list.

		Returns:
			bool
		"""
		return self._get_attribute('isPrependDut')
	@IsPrependDut.setter
	def IsPrependDut(self, value):
		self._set_attribute('isPrependDut', value)

	@property
	def IsSendingAsEro(self):
		"""If enabled, the entire configuration would go as ERO.

		Returns:
			bool
		"""
		return self._get_attribute('isSendingAsEro')
	@IsSendingAsEro.setter
	def IsSendingAsEro(self, value):
		self._set_attribute('isSendingAsEro', value)

	@property
	def IsSendingAsSero(self):
		"""If enabled, the entire configuration would go as SERO.

		Returns:
			bool
		"""
		return self._get_attribute('isSendingAsSero')
	@IsSendingAsSero.setter
	def IsSendingAsSero(self, value):
		self._set_attribute('isSendingAsSero', value)

	@property
	def SubObjectList(self):
		"""The sub-object list for this ERO/SERO can be configured by typing it as a string. Input String: = NULL| [<Subobject> ;< Subobject list>] Subobject: = <AS :< 1-65535> :< S|L>| <IP :< IP Addr>/<1-32> :< S|L> IP Addr: = <0-255>.<0-255>.<0-255>.<0-255> NULL: =Example. IP:2.2.2.2/24:S;AS:100:L;IP:33.33.33.33/32:S

		Returns:
			str
		"""
		return self._get_attribute('subObjectList')
	@SubObjectList.setter
	def SubObjectList(self, value):
		self._set_attribute('subObjectList', value)

	@property
	def TunnelLeafCount(self):
		"""The count of tunnel leaf.

		Returns:
			number
		"""
		return self._get_attribute('tunnelLeafCount')
	@TunnelLeafCount.setter
	def TunnelLeafCount(self, value):
		self._set_attribute('tunnelLeafCount', value)

	@property
	def TunnelLeafHopType(self):
		"""It is enabled if Append Leaf is enabled. Based on the input, corresponding L bit in the packet is set.

		Returns:
			str(strict|loose)
		"""
		return self._get_attribute('tunnelLeafHopType')
	@TunnelLeafHopType.setter
	def TunnelLeafHopType(self, value):
		self._set_attribute('tunnelLeafHopType', value)

	@property
	def TunnelLeafIpStart(self):
		"""It contains the start IP address of leaf for which the ERO/SERO will be configured.

		Returns:
			str
		"""
		return self._get_attribute('tunnelLeafIpStart')
	@TunnelLeafIpStart.setter
	def TunnelLeafIpStart(self, value):
		self._set_attribute('tunnelLeafIpStart', value)

	@property
	def TunnelLeafPrefixLength(self):
		"""Prefix length of tunnel leaf.

		Returns:
			number
		"""
		return self._get_attribute('tunnelLeafPrefixLength')
	@TunnelLeafPrefixLength.setter
	def TunnelLeafPrefixLength(self, value):
		self._set_attribute('tunnelLeafPrefixLength', value)

	def update(self, DutHopType=None, DutPrefixLength=None, Enabled=None, IsAppendTunnelLeaf=None, IsPrependDut=None, IsSendingAsEro=None, IsSendingAsSero=None, SubObjectList=None, TunnelLeafCount=None, TunnelLeafHopType=None, TunnelLeafIpStart=None, TunnelLeafPrefixLength=None):
		"""Updates a child instance of tunnelHeadToLeaf on the server.

		Args:
			DutHopType (str(strict|loose)): Based on the input, the corresponding L bit in the packet is set.
			DutPrefixLength (number): Prefix length of DUT.
			Enabled (bool): It enables or disables the ERO/SERO specific configuration.
			IsAppendTunnelLeaf (bool): If enabled, this appends the tunnel leaf at the end of the ERO/SERO list in the packet.
			IsPrependDut (bool): Enables prepend DUT to the ERO/SERO list.
			IsSendingAsEro (bool): If enabled, the entire configuration would go as ERO.
			IsSendingAsSero (bool): If enabled, the entire configuration would go as SERO.
			SubObjectList (str): The sub-object list for this ERO/SERO can be configured by typing it as a string. Input String: = NULL| [<Subobject> ;< Subobject list>] Subobject: = <AS :< 1-65535> :< S|L>| <IP :< IP Addr>/<1-32> :< S|L> IP Addr: = <0-255>.<0-255>.<0-255>.<0-255> NULL: =Example. IP:2.2.2.2/24:S;AS:100:L;IP:33.33.33.33/32:S
			TunnelLeafCount (number): The count of tunnel leaf.
			TunnelLeafHopType (str(strict|loose)): It is enabled if Append Leaf is enabled. Based on the input, corresponding L bit in the packet is set.
			TunnelLeafIpStart (str): It contains the start IP address of leaf for which the ERO/SERO will be configured.
			TunnelLeafPrefixLength (number): Prefix length of tunnel leaf.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, DutHopType=None, DutPrefixLength=None, Enabled=None, IsAppendTunnelLeaf=None, IsPrependDut=None, IsSendingAsEro=None, IsSendingAsSero=None, SubObjectList=None, TunnelLeafCount=None, TunnelLeafHopType=None, TunnelLeafIpStart=None, TunnelLeafPrefixLength=None):
		"""Adds a new tunnelHeadToLeaf node on the server and retrieves it in this instance.

		Args:
			DutHopType (str(strict|loose)): Based on the input, the corresponding L bit in the packet is set.
			DutPrefixLength (number): Prefix length of DUT.
			Enabled (bool): It enables or disables the ERO/SERO specific configuration.
			IsAppendTunnelLeaf (bool): If enabled, this appends the tunnel leaf at the end of the ERO/SERO list in the packet.
			IsPrependDut (bool): Enables prepend DUT to the ERO/SERO list.
			IsSendingAsEro (bool): If enabled, the entire configuration would go as ERO.
			IsSendingAsSero (bool): If enabled, the entire configuration would go as SERO.
			SubObjectList (str): The sub-object list for this ERO/SERO can be configured by typing it as a string. Input String: = NULL| [<Subobject> ;< Subobject list>] Subobject: = <AS :< 1-65535> :< S|L>| <IP :< IP Addr>/<1-32> :< S|L> IP Addr: = <0-255>.<0-255>.<0-255>.<0-255> NULL: =Example. IP:2.2.2.2/24:S;AS:100:L;IP:33.33.33.33/32:S
			TunnelLeafCount (number): The count of tunnel leaf.
			TunnelLeafHopType (str(strict|loose)): It is enabled if Append Leaf is enabled. Based on the input, corresponding L bit in the packet is set.
			TunnelLeafIpStart (str): It contains the start IP address of leaf for which the ERO/SERO will be configured.
			TunnelLeafPrefixLength (number): Prefix length of tunnel leaf.

		Returns:
			self: This instance with all currently retrieved tunnelHeadToLeaf data using find and the newly added tunnelHeadToLeaf data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the tunnelHeadToLeaf data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, DutHopType=None, DutPrefixLength=None, Enabled=None, HeadIpStart=None, IsAppendTunnelLeaf=None, IsPrependDut=None, IsSendingAsEro=None, IsSendingAsSero=None, SubObjectList=None, TunnelLeafCount=None, TunnelLeafHopType=None, TunnelLeafIpStart=None, TunnelLeafPrefixLength=None):
		"""Finds and retrieves tunnelHeadToLeaf data from the server.

		All named parameters support regex and can be used to selectively retrieve tunnelHeadToLeaf data from the server.
		By default the find method takes no parameters and will retrieve all tunnelHeadToLeaf data from the server.

		Args:
			DutHopType (str(strict|loose)): Based on the input, the corresponding L bit in the packet is set.
			DutPrefixLength (number): Prefix length of DUT.
			Enabled (bool): It enables or disables the ERO/SERO specific configuration.
			HeadIpStart (str): It is the tunnel head IP address for which the ERO/SERO is being configured.
			IsAppendTunnelLeaf (bool): If enabled, this appends the tunnel leaf at the end of the ERO/SERO list in the packet.
			IsPrependDut (bool): Enables prepend DUT to the ERO/SERO list.
			IsSendingAsEro (bool): If enabled, the entire configuration would go as ERO.
			IsSendingAsSero (bool): If enabled, the entire configuration would go as SERO.
			SubObjectList (str): The sub-object list for this ERO/SERO can be configured by typing it as a string. Input String: = NULL| [<Subobject> ;< Subobject list>] Subobject: = <AS :< 1-65535> :< S|L>| <IP :< IP Addr>/<1-32> :< S|L> IP Addr: = <0-255>.<0-255>.<0-255>.<0-255> NULL: =Example. IP:2.2.2.2/24:S;AS:100:L;IP:33.33.33.33/32:S
			TunnelLeafCount (number): The count of tunnel leaf.
			TunnelLeafHopType (str(strict|loose)): It is enabled if Append Leaf is enabled. Based on the input, corresponding L bit in the packet is set.
			TunnelLeafIpStart (str): It contains the start IP address of leaf for which the ERO/SERO will be configured.
			TunnelLeafPrefixLength (number): Prefix length of tunnel leaf.

		Returns:
			self: This instance with matching tunnelHeadToLeaf data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of tunnelHeadToLeaf data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the tunnelHeadToLeaf data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MplsRouteRange(Base):
	"""The MplsRouteRange class encapsulates a user managed mplsRouteRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MplsRouteRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'mplsRouteRange'

	def __init__(self, parent):
		super(MplsRouteRange, self).__init__(parent)

	@property
	def AsSegment(self):
		"""An instance of the AsSegment class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.assegment.AsSegment)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.assegment import AsSegment
		return AsSegment(self)._select()

	@property
	def Cluster(self):
		"""An instance of the Cluster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster.Cluster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster import Cluster
		return Cluster(self)._select()

	@property
	def Community(self):
		"""An instance of the Community class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.community.Community)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.community import Community
		return Community(self)._select()

	@property
	def ExtendedCommunity(self):
		"""An instance of the ExtendedCommunity class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.extendedcommunity.ExtendedCommunity)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.extendedcommunity import ExtendedCommunity
		return ExtendedCommunity(self)._select()

	@property
	def Flapping(self):
		"""An instance of the Flapping class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.flapping.Flapping)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.flapping import Flapping
		return Flapping(self)._select()

	@property
	def LabelSpace(self):
		"""An instance of the LabelSpace class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelspace.LabelSpace)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelspace import LabelSpace
		return LabelSpace(self)._select()

	@property
	def AdvertiseNextHopAsV4(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('advertiseNextHopAsV4')
	@AdvertiseNextHopAsV4.setter
	def AdvertiseNextHopAsV4(self, value):
		self._set_attribute('advertiseNextHopAsV4', value)

	@property
	def AggregatorAsNum(self):
		"""If enabled, sets the AS associated with the aggregator router ID.

		Returns:
			number
		"""
		return self._get_attribute('aggregatorAsNum')
	@AggregatorAsNum.setter
	def AggregatorAsNum(self, value):
		self._set_attribute('aggregatorAsNum', value)

	@property
	def AggregatorIpAddress(self):
		"""If enabled, generates an aggregator attribute that indicates the router ID of the router that aggregated two or more routes into one.

		Returns:
			str
		"""
		return self._get_attribute('aggregatorIpAddress')
	@AggregatorIpAddress.setter
	def AggregatorIpAddress(self, value):
		self._set_attribute('aggregatorIpAddress', value)

	@property
	def AsPathSetMode(self):
		"""The mode to set the AsPath. Possible values include:+ noInclude+ includeAsSeq+ includeAsSet+ includeAsSeqConf+ includeAsSetConf+ prependAs

		Returns:
			str(noInclude|includeAsSeq|includeAsSet|includeAsSeqConf|includeAsSetConf|prependAs)
		"""
		return self._get_attribute('asPathSetMode')
	@AsPathSetMode.setter
	def AsPathSetMode(self, value):
		self._set_attribute('asPathSetMode', value)

	@property
	def EnableAggregator(self):
		"""If enabled, generates an aggregator attribute that indicates the router ID that aggregated two or more routes into one.

		Returns:
			bool
		"""
		return self._get_attribute('enableAggregator')
	@EnableAggregator.setter
	def EnableAggregator(self, value):
		self._set_attribute('enableAggregator', value)

	@property
	def EnableAggregatorIdIncrementMode(self):
		"""If true, Causes the AS field to be incremented for each neighbor session generated for the range of neighbor addresses in the AGGREGATOR attribute. (default = 1)

		Returns:
			bool
		"""
		return self._get_attribute('enableAggregatorIdIncrementMode')
	@EnableAggregatorIdIncrementMode.setter
	def EnableAggregatorIdIncrementMode(self, value):
		self._set_attribute('enableAggregatorIdIncrementMode', value)

	@property
	def EnableAsPath(self):
		"""If true, Enables the generation of AS Path related items.

		Returns:
			bool
		"""
		return self._get_attribute('enableAsPath')
	@EnableAsPath.setter
	def EnableAsPath(self, value):
		self._set_attribute('enableAsPath', value)

	@property
	def EnableAtomicAttribute(self):
		"""If enabled, sets the attribute bit that indicates that the router has aggregated two or more prefixes together into one.

		Returns:
			bool
		"""
		return self._get_attribute('enableAtomicAttribute')
	@EnableAtomicAttribute.setter
	def EnableAtomicAttribute(self, value):
		self._set_attribute('enableAtomicAttribute', value)

	@property
	def EnableCluster(self):
		"""If enabled, generates a list of BGP clusters that a particular route has passed through.

		Returns:
			bool
		"""
		return self._get_attribute('enableCluster')
	@EnableCluster.setter
	def EnableCluster(self, value):
		self._set_attribute('enableCluster', value)

	@property
	def EnableCommunity(self):
		"""If enabled, indicates that a community attribute should be added to the BGP entry.

		Returns:
			bool
		"""
		return self._get_attribute('enableCommunity')
	@EnableCommunity.setter
	def EnableCommunity(self, value):
		self._set_attribute('enableCommunity', value)

	@property
	def EnableGenerateUniqueRoutes(self):
		"""When true, each router generates a different IP address range.

		Returns:
			bool
		"""
		return self._get_attribute('enableGenerateUniqueRoutes')
	@EnableGenerateUniqueRoutes.setter
	def EnableGenerateUniqueRoutes(self, value):
		self._set_attribute('enableGenerateUniqueRoutes', value)

	@property
	def EnableIncludeLoopback(self):
		"""If true, will include the loopback address (127.0.0.1) if it is in the generated network range. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeLoopback')
	@EnableIncludeLoopback.setter
	def EnableIncludeLoopback(self, value):
		self._set_attribute('enableIncludeLoopback', value)

	@property
	def EnableIncludeMulticast(self):
		"""If true, will include multicast addresses if they are in the generated network range. The SAFI used for multicast addresses is dictated by the setting of the enableProperSafi option. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeMulticast')
	@EnableIncludeMulticast.setter
	def EnableIncludeMulticast(self, value):
		self._set_attribute('enableIncludeMulticast', value)

	@property
	def EnableLocalPref(self):
		"""Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableLocalPref')
	@EnableLocalPref.setter
	def EnableLocalPref(self, value):
		self._set_attribute('enableLocalPref', value)

	@property
	def EnableMed(self):
		"""Enables the generation of a MULTI EXIT DISCRIMINATOR attribute, based on the information in MED. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableMed')
	@EnableMed.setter
	def EnableMed(self, value):
		self._set_attribute('enableMed', value)

	@property
	def EnableNextHop(self):
		"""Enables the generation of a NEXT HOP attribute, based on information in nextHopIpAddress and nextHopMode (default = true)

		Returns:
			bool
		"""
		return self._get_attribute('enableNextHop')
	@EnableNextHop.setter
	def EnableNextHop(self, value):
		self._set_attribute('enableNextHop', value)

	@property
	def EnableOrigin(self):
		"""Enables the generation of an ORIGIN attribute, based on information in originProtocol. (default = true)

		Returns:
			bool
		"""
		return self._get_attribute('enableOrigin')
	@EnableOrigin.setter
	def EnableOrigin(self, value):
		self._set_attribute('enableOrigin', value)

	@property
	def EnableOriginatorId(self):
		"""Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId.

		Returns:
			bool
		"""
		return self._get_attribute('enableOriginatorId')
	@EnableOriginatorId.setter
	def EnableOriginatorId(self, value):
		self._set_attribute('enableOriginatorId', value)

	@property
	def EnableTraditionalNlriUpdate(self):
		"""If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)

		Returns:
			bool
		"""
		return self._get_attribute('enableTraditionalNlriUpdate')
	@EnableTraditionalNlriUpdate.setter
	def EnableTraditionalNlriUpdate(self, value):
		self._set_attribute('enableTraditionalNlriUpdate', value)

	@property
	def Enabled(self):
		"""If true, enables the MPLS route range.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def EndOfRib(self):
		"""If true, enables end of rib

		Returns:
			bool
		"""
		return self._get_attribute('endOfRib')
	@EndOfRib.setter
	def EndOfRib(self, value):
		self._set_attribute('endOfRib', value)

	@property
	def FromPacking(self):
		"""The minimum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('fromPacking')
	@FromPacking.setter
	def FromPacking(self, value):
		self._set_attribute('fromPacking', value)

	@property
	def FromPrefix(self):
		"""The first prefix length to generate based on the networkAddress and numRanges. (default = 24)

		Returns:
			number
		"""
		return self._get_attribute('fromPrefix')
	@FromPrefix.setter
	def FromPrefix(self, value):
		self._set_attribute('fromPrefix', value)

	@property
	def IpType(self):
		"""The Internet Protocol type for the addresses.

		Returns:
			str(ipAny|ipv4|ipv6)
		"""
		return self._get_attribute('ipType')
	@IpType.setter
	def IpType(self, value):
		self._set_attribute('ipType', value)

	@property
	def IterationStep(self):
		"""During prefix generation, the increment between prefixes. (default = 1)

		Returns:
			number
		"""
		return self._get_attribute('iterationStep')
	@IterationStep.setter
	def IterationStep(self, value):
		self._set_attribute('iterationStep', value)

	@property
	def LocalPref(self):
		"""The local preference value for the routes with the LOCAL PREF attribute. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('localPref')
	@LocalPref.setter
	def LocalPref(self, value):
		self._set_attribute('localPref', value)

	@property
	def Med(self):
		"""The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('med')
	@Med.setter
	def Med(self, value):
		self._set_attribute('med', value)

	@property
	def NetworkAddress(self):
		"""The network address used for the generated prefixes, in either IPv4 or IPv6 format. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('networkAddress')
	@NetworkAddress.setter
	def NetworkAddress(self, value):
		self._set_attribute('networkAddress', value)

	@property
	def NextHopIpAddress(self):
		"""The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('nextHopIpAddress')
	@NextHopIpAddress.setter
	def NextHopIpAddress(self, value):
		self._set_attribute('nextHopIpAddress', value)

	@property
	def NextHopMode(self):
		"""Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.

		Returns:
			str(fixed|nextHopIncrement|incrementPerPrefix)
		"""
		return self._get_attribute('nextHopMode')
	@NextHopMode.setter
	def NextHopMode(self, value):
		self._set_attribute('nextHopMode', value)

	@property
	def NextHopSetMode(self):
		"""Indicates now to set the next hop IP address.

		Returns:
			str(setManually|sameAsLocalIp)
		"""
		return self._get_attribute('nextHopSetMode')
	@NextHopSetMode.setter
	def NextHopSetMode(self, value):
		self._set_attribute('nextHopSetMode', value)

	@property
	def NumRoutes(self):
		"""The number of prefixes (routes) to generate for this routeItem. (default = 1)

		Returns:
			number
		"""
		return self._get_attribute('numRoutes')
	@NumRoutes.setter
	def NumRoutes(self, value):
		self._set_attribute('numRoutes', value)

	@property
	def OriginProtocol(self):
		"""An indication of where the route entry originated.

		Returns:
			str(igp|egp|incomplete)
		"""
		return self._get_attribute('originProtocol')
	@OriginProtocol.setter
	def OriginProtocol(self, value):
		self._set_attribute('originProtocol', value)

	@property
	def OriginatorId(self):
		"""The ID for the router that originated the route.

		Returns:
			str
		"""
		return self._get_attribute('originatorId')
	@OriginatorId.setter
	def OriginatorId(self, value):
		self._set_attribute('originatorId', value)

	@property
	def ThruPacking(self):
		"""The maximum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking.

		Returns:
			number
		"""
		return self._get_attribute('thruPacking')
	@ThruPacking.setter
	def ThruPacking(self, value):
		self._set_attribute('thruPacking', value)

	@property
	def ThruPrefix(self):
		"""The last prefix length to generate based on the networkAddress and numRanges. (default = 24)

		Returns:
			number
		"""
		return self._get_attribute('thruPrefix')
	@ThruPrefix.setter
	def ThruPrefix(self, value):
		self._set_attribute('thruPrefix', value)

	def update(self, AdvertiseNextHopAsV4=None, AggregatorAsNum=None, AggregatorIpAddress=None, AsPathSetMode=None, EnableAggregator=None, EnableAggregatorIdIncrementMode=None, EnableAsPath=None, EnableAtomicAttribute=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableIncludeLoopback=None, EnableIncludeMulticast=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginatorId=None, EnableTraditionalNlriUpdate=None, Enabled=None, EndOfRib=None, FromPacking=None, FromPrefix=None, IpType=None, IterationStep=None, LocalPref=None, Med=None, NetworkAddress=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, NumRoutes=None, OriginProtocol=None, OriginatorId=None, ThruPacking=None, ThruPrefix=None):
		"""Updates a child instance of mplsRouteRange on the server.

		Args:
			AdvertiseNextHopAsV4 (bool): NOT DEFINED
			AggregatorAsNum (number): If enabled, sets the AS associated with the aggregator router ID.
			AggregatorIpAddress (str): If enabled, generates an aggregator attribute that indicates the router ID of the router that aggregated two or more routes into one.
			AsPathSetMode (str(noInclude|includeAsSeq|includeAsSet|includeAsSeqConf|includeAsSetConf|prependAs)): The mode to set the AsPath. Possible values include:+ noInclude+ includeAsSeq+ includeAsSet+ includeAsSeqConf+ includeAsSetConf+ prependAs
			EnableAggregator (bool): If enabled, generates an aggregator attribute that indicates the router ID that aggregated two or more routes into one.
			EnableAggregatorIdIncrementMode (bool): If true, Causes the AS field to be incremented for each neighbor session generated for the range of neighbor addresses in the AGGREGATOR attribute. (default = 1)
			EnableAsPath (bool): If true, Enables the generation of AS Path related items.
			EnableAtomicAttribute (bool): If enabled, sets the attribute bit that indicates that the router has aggregated two or more prefixes together into one.
			EnableCluster (bool): If enabled, generates a list of BGP clusters that a particular route has passed through.
			EnableCommunity (bool): If enabled, indicates that a community attribute should be added to the BGP entry.
			EnableGenerateUniqueRoutes (bool): When true, each router generates a different IP address range.
			EnableIncludeLoopback (bool): If true, will include the loopback address (127.0.0.1) if it is in the generated network range. (default = false)
			EnableIncludeMulticast (bool): If true, will include multicast addresses if they are in the generated network range. The SAFI used for multicast addresses is dictated by the setting of the enableProperSafi option. (default = false)
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute, based on the information in MED. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute, based on information in nextHopIpAddress and nextHopMode (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute, based on information in originProtocol. (default = true)
			EnableOriginatorId (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId.
			EnableTraditionalNlriUpdate (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): If true, enables the MPLS route range.
			EndOfRib (bool): If true, enables end of rib
			FromPacking (number): The minimum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking. (default = 0)
			FromPrefix (number): The first prefix length to generate based on the networkAddress and numRanges. (default = 24)
			IpType (str(ipAny|ipv4|ipv6)): The Internet Protocol type for the addresses.
			IterationStep (number): During prefix generation, the increment between prefixes. (default = 1)
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NetworkAddress (str): The network address used for the generated prefixes, in either IPv4 or IPv6 format. (default = 0.0.0.0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(fixed|nextHopIncrement|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(setManually|sameAsLocalIp)): Indicates now to set the next hop IP address.
			NumRoutes (number): The number of prefixes (routes) to generate for this routeItem. (default = 1)
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The ID for the router that originated the route.
			ThruPacking (number): The maximum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking.
			ThruPrefix (number): The last prefix length to generate based on the networkAddress and numRanges. (default = 24)

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AdvertiseNextHopAsV4=None, AggregatorAsNum=None, AggregatorIpAddress=None, AsPathSetMode=None, EnableAggregator=None, EnableAggregatorIdIncrementMode=None, EnableAsPath=None, EnableAtomicAttribute=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableIncludeLoopback=None, EnableIncludeMulticast=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginatorId=None, EnableTraditionalNlriUpdate=None, Enabled=None, EndOfRib=None, FromPacking=None, FromPrefix=None, IpType=None, IterationStep=None, LocalPref=None, Med=None, NetworkAddress=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, NumRoutes=None, OriginProtocol=None, OriginatorId=None, ThruPacking=None, ThruPrefix=None):
		"""Adds a new mplsRouteRange node on the server and retrieves it in this instance.

		Args:
			AdvertiseNextHopAsV4 (bool): NOT DEFINED
			AggregatorAsNum (number): If enabled, sets the AS associated with the aggregator router ID.
			AggregatorIpAddress (str): If enabled, generates an aggregator attribute that indicates the router ID of the router that aggregated two or more routes into one.
			AsPathSetMode (str(noInclude|includeAsSeq|includeAsSet|includeAsSeqConf|includeAsSetConf|prependAs)): The mode to set the AsPath. Possible values include:+ noInclude+ includeAsSeq+ includeAsSet+ includeAsSeqConf+ includeAsSetConf+ prependAs
			EnableAggregator (bool): If enabled, generates an aggregator attribute that indicates the router ID that aggregated two or more routes into one.
			EnableAggregatorIdIncrementMode (bool): If true, Causes the AS field to be incremented for each neighbor session generated for the range of neighbor addresses in the AGGREGATOR attribute. (default = 1)
			EnableAsPath (bool): If true, Enables the generation of AS Path related items.
			EnableAtomicAttribute (bool): If enabled, sets the attribute bit that indicates that the router has aggregated two or more prefixes together into one.
			EnableCluster (bool): If enabled, generates a list of BGP clusters that a particular route has passed through.
			EnableCommunity (bool): If enabled, indicates that a community attribute should be added to the BGP entry.
			EnableGenerateUniqueRoutes (bool): When true, each router generates a different IP address range.
			EnableIncludeLoopback (bool): If true, will include the loopback address (127.0.0.1) if it is in the generated network range. (default = false)
			EnableIncludeMulticast (bool): If true, will include multicast addresses if they are in the generated network range. The SAFI used for multicast addresses is dictated by the setting of the enableProperSafi option. (default = false)
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute, based on the information in MED. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute, based on information in nextHopIpAddress and nextHopMode (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute, based on information in originProtocol. (default = true)
			EnableOriginatorId (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId.
			EnableTraditionalNlriUpdate (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): If true, enables the MPLS route range.
			EndOfRib (bool): If true, enables end of rib
			FromPacking (number): The minimum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking. (default = 0)
			FromPrefix (number): The first prefix length to generate based on the networkAddress and numRanges. (default = 24)
			IpType (str(ipAny|ipv4|ipv6)): The Internet Protocol type for the addresses.
			IterationStep (number): During prefix generation, the increment between prefixes. (default = 1)
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NetworkAddress (str): The network address used for the generated prefixes, in either IPv4 or IPv6 format. (default = 0.0.0.0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(fixed|nextHopIncrement|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(setManually|sameAsLocalIp)): Indicates now to set the next hop IP address.
			NumRoutes (number): The number of prefixes (routes) to generate for this routeItem. (default = 1)
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The ID for the router that originated the route.
			ThruPacking (number): The maximum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking.
			ThruPrefix (number): The last prefix length to generate based on the networkAddress and numRanges. (default = 24)

		Returns:
			self: This instance with all currently retrieved mplsRouteRange data using find and the newly added mplsRouteRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the mplsRouteRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AdvertiseNextHopAsV4=None, AggregatorAsNum=None, AggregatorIpAddress=None, AsPathSetMode=None, EnableAggregator=None, EnableAggregatorIdIncrementMode=None, EnableAsPath=None, EnableAtomicAttribute=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableIncludeLoopback=None, EnableIncludeMulticast=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginatorId=None, EnableTraditionalNlriUpdate=None, Enabled=None, EndOfRib=None, FromPacking=None, FromPrefix=None, IpType=None, IterationStep=None, LocalPref=None, Med=None, NetworkAddress=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, NumRoutes=None, OriginProtocol=None, OriginatorId=None, ThruPacking=None, ThruPrefix=None):
		"""Finds and retrieves mplsRouteRange data from the server.

		All named parameters support regex and can be used to selectively retrieve mplsRouteRange data from the server.
		By default the find method takes no parameters and will retrieve all mplsRouteRange data from the server.

		Args:
			AdvertiseNextHopAsV4 (bool): NOT DEFINED
			AggregatorAsNum (number): If enabled, sets the AS associated with the aggregator router ID.
			AggregatorIpAddress (str): If enabled, generates an aggregator attribute that indicates the router ID of the router that aggregated two or more routes into one.
			AsPathSetMode (str(noInclude|includeAsSeq|includeAsSet|includeAsSeqConf|includeAsSetConf|prependAs)): The mode to set the AsPath. Possible values include:+ noInclude+ includeAsSeq+ includeAsSet+ includeAsSeqConf+ includeAsSetConf+ prependAs
			EnableAggregator (bool): If enabled, generates an aggregator attribute that indicates the router ID that aggregated two or more routes into one.
			EnableAggregatorIdIncrementMode (bool): If true, Causes the AS field to be incremented for each neighbor session generated for the range of neighbor addresses in the AGGREGATOR attribute. (default = 1)
			EnableAsPath (bool): If true, Enables the generation of AS Path related items.
			EnableAtomicAttribute (bool): If enabled, sets the attribute bit that indicates that the router has aggregated two or more prefixes together into one.
			EnableCluster (bool): If enabled, generates a list of BGP clusters that a particular route has passed through.
			EnableCommunity (bool): If enabled, indicates that a community attribute should be added to the BGP entry.
			EnableGenerateUniqueRoutes (bool): When true, each router generates a different IP address range.
			EnableIncludeLoopback (bool): If true, will include the loopback address (127.0.0.1) if it is in the generated network range. (default = false)
			EnableIncludeMulticast (bool): If true, will include multicast addresses if they are in the generated network range. The SAFI used for multicast addresses is dictated by the setting of the enableProperSafi option. (default = false)
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute, based on the information in MED. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute, based on information in nextHopIpAddress and nextHopMode (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute, based on information in originProtocol. (default = true)
			EnableOriginatorId (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId.
			EnableTraditionalNlriUpdate (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): If true, enables the MPLS route range.
			EndOfRib (bool): If true, enables end of rib
			FromPacking (number): The minimum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking. (default = 0)
			FromPrefix (number): The first prefix length to generate based on the networkAddress and numRanges. (default = 24)
			IpType (str(ipAny|ipv4|ipv6)): The Internet Protocol type for the addresses.
			IterationStep (number): During prefix generation, the increment between prefixes. (default = 1)
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NetworkAddress (str): The network address used for the generated prefixes, in either IPv4 or IPv6 format. (default = 0.0.0.0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(fixed|nextHopIncrement|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(setManually|sameAsLocalIp)): Indicates now to set the next hop IP address.
			NumRoutes (number): The number of prefixes (routes) to generate for this routeItem. (default = 1)
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The ID for the router that originated the route.
			ThruPacking (number): The maximum number of routes to pack into an UPDATE message. Random numbers are chosen from the range fromPacking to toPacking.
			ThruPrefix (number): The last prefix length to generate based on the networkAddress and numRanges. (default = 24)

		Returns:
			self: This instance with matching mplsRouteRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of mplsRouteRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the mplsRouteRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
